@@ -1,11 +1,10 @@
 #!/usr/bin/perl
-# Feeds.pm 
+# Feeds.pm
 # Copyright (c) 2006 Jonathan Rockway <jrockway@cpan.org>
 
 package Angerwhale::Model::Feeds;
-use Angerwhale;
-
-__PACKAGE__->config->{feeds} = Angerwhale->config->{feeds};
+use strict;
+use warnings;
 
 use base qw(Catalyst::Model::XML::Feed);
 
@@ -15,6 +14,21 @@ Angerwhale model for obtaining sidebar RSS feeds.
   
 See L<Catalyst::Model::XML::Feed> and L<Angerwhale>.
 
+=head1 METHODS
+
+=head2 COMPONENT
+
+Merge "feeds" global config key into local config.
+
 =cut
 
+sub COMPONENT {
+    my $class = shift;
+    my $app   = $_[0];
+    my $args  = $_[1];
+    
+    $args->{feeds} = $app->config->{feeds};
+    $class->NEXT::COMPONENT(@_);
+}
+
 1;
